syntax = "proto3";
package tendermint.types;

option go_package = "github.com/tendermint/tendermint/proto/tendermint/types";

import "gogoproto/gogo.proto";
import "tendermint/types/types.proto";
import "tendermint/types/evidence.proto";

message Block {
  Header                        header      = 1 [(gogoproto.nullable) = false];
  Data                          data        = 2 [(gogoproto.nullable) = false];
  tendermint.types.EvidenceList evidence    = 3 [(gogoproto.nullable) = false];
  Commit                        last_commit = 4;
}
