syntax = "proto3";
package sentinel.node.v2;

import "gogoproto/gogo.proto";
import "sentinel/node/v2/node.proto";
import "sentinel/node/v2/params.proto";

option go_package            = "github.com/sentinel-official/hub/x/node/types";
option (gogoproto.equal_all) = false;
option (gogoproto.goproto_getters_all) = false;

message GenesisState {
  repeated Node nodes = 1 [ (gogoproto.nullable) = false ];
  Params params       = 2 [ (gogoproto.nullable) = false ];
}
