syntax = "proto3";
package sentinel.provider.v2;

import "gogoproto/gogo.proto";
import "google/protobuf/timestamp.proto";
import "sentinel/types/v1/status.proto";

option go_package = "github.com/sentinel-official/hub/x/provider/types";
option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

message Provider {
  string address                      = 1;
  string name                         = 2;
  string identity                     = 3;
  string website                      = 4;
  string description                  = 5;
  sentinel.types.v1.Status status     = 6;
  google.protobuf.Timestamp status_at = 7
      [ (gogoproto.nullable) = false, (gogoproto.stdtime) = true ];
}
