syntax = "proto3";
package sentinel.session.v2;

import "gogoproto/gogo.proto";
import "google/protobuf/duration.proto";
import "sentinel/types/v1/bandwidth.proto";

option go_package = "github.com/sentinel-official/hub/x/session/types";
option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

message Proof {
  uint64 id                             = 1 [ (gogoproto.customname) = "ID" ];
  sentinel.types.v1.Bandwidth bandwidth = 2 [ (gogoproto.nullable) = false ];
  google.protobuf.Duration duration     = 3
      [ (gogoproto.stdduration) = true, (gogoproto.nullable) = false ];
}
