syntax = "proto3";
package cosmos.mint.v1beta1;

import "gogoproto/gogo.proto";
import "cosmos/mint/v1beta1/mint.proto";

option go_package = "github.com/cosmos/cosmos-sdk/x/mint/types";

// GenesisState defines the mint module's genesis state.
message GenesisState {
  // minter is a space for holding current inflation information.
  Minter minter = 1 [(gogoproto.nullable) = false];

  // params defines all the paramaters of the module.
  Params params = 2 [(gogoproto.nullable) = false];
}
