
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Inflation(_message.Message):
    __slots__ = ['max', 'min', 'rate_change', 'timestamp']
    MAX_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    RATE_CHANGE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    max: str
    min: str
    rate_change: str
    timestamp: _timestamp_pb2.Timestamp

    def __init__(self, max: _Optional[str]=..., min: _Optional[str]=..., rate_change: _Optional[str]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...
