syntax = "proto3";
package cosmos.genutil.v1beta1;

import "gogoproto/gogo.proto";

option go_package = "github.com/cosmos/cosmos-sdk/x/genutil/types";

// GenesisState defines the raw genesis transaction in JSON.
message GenesisState {
  // gen_txs defines the genesis transactions.
  repeated bytes gen_txs = 1 [
    (gogoproto.casttype) = "encoding/json.RawMessage",
    (gogoproto.jsontag)  = "gentxs",
    (gogoproto.moretags) = "yaml:\"gentxs\""
  ];
}
